LdtkLayerInstance class

Layer instance in a level.

Constructors

LdtkLayerInstance({required String identifier, required String type, required int gridSize, required List<LdtkEntityInstance> entityInstances, required List<LdtkTileInstance> gridTiles, required List<int> intGridCsv, required int cWid, required int cHei, int? tilesetDefUid, String? tilesetRelPath})
const
LdtkLayerInstance.fromJson(Map<String, dynamic> json)
factory

Properties

cHei → int
final
cWid → int
final
entityInstances → List<LdtkEntityInstance>
final
gridSize → int
final
gridTiles → List<LdtkTileInstance>
final
hashCode → int
The hash code for this object.
no setterinherited
identifier → String
final
intGridCsv → List<int>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tilesetDefUid → int?
final
tilesetRelPath → String?
final
type → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited