LdtkParserUtils class
Utility functions shared between LDtk parsers.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
clearImageCache(
) → void - Clears the image cache.
-
getBasePath(
String filePath) → String - Extracts the base path from a file path.
-
loadImage(
String path) → Future< Image> - Loads an image from the given asset path with caching.
-
parseFieldInstances(
List fieldInstances) → Map< String, dynamic> - Parses LDtk field instances array to a Map
-
parseHexColor(
String? hexColor) → Color? - Parses a hex color string (e.g., "#FF0000") to a Flutter Color.
-
parseIntColor(
int? colorInt) → Color? - Parses an integer color value to a Flutter Color.