LdtkTileLayer class

Represents a tile layer with its tileset image and tile data.

Constructors

LdtkTileLayer({required String layerName, required Image tilesetImage, required int tileSize, required List<LdtkTileInstance> tiles})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
layerName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tiles List<LdtkTileInstance>
final
tilesetImage Image
final
tileSize int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited